<template>
  <section
    :class="{ ['color' + container.shop_color]: true, ['layout' + container.shop_style]: true }"
    class="containers">
    <div class="shop-html">
      <div
        v-if="container.shop_style == 1"
        class="shop-body">
        <div class="headerwidthcontainer">
          <div id="gear">
            <img src="/images/shop/containers/container-gear.png">
          </div>
          <div id="shopname">{{ container.name }}</div>
          <div id="yatlogo">
            <img
              id="yatlogoimg"
              :src="logo"
              width="98"
              height="81">
          </div>
        </div>
        <div class="contentwidthcontainer">
          <img
            id="containertop"
            src="/images/shop/containers/containerbgtop.png">
          <div
            v-if="container.admin"
            id="menu">
            <ul
              id="nav"
              class="tab-buttons">
              <router-link
                :to="{name: 'containersmain'}"
                tag="li">
                <a
                  :class="{selected: (this.$route.name === 'containersmain')}"
                  class="tab">Main Page</a>
              </router-link>
              <router-link
                :to="{name: 'containersprice'}"
                tag="li">
                <a
                  :class="{selected: (this.$route.name === 'containersprice')}"
                  class="tab">Edit Prices
                </a>
              </router-link>
              <router-link
                :to="{name: 'containersorders'}"
                tag="li">
                <a
                  :class="{selected: (this.$route.name === 'containersorders')}"
                  class="tab">Orders
                </a>
              </router-link>
              <router-link
                :to="{name: 'containersaccounting'}"
                tag="li">
                <a
                  :class="{selected: (this.$route.name === 'containersaccounting')}"
                  class="tab">Accounting
                </a>
              </router-link>
              <div class="clear"/>
            </ul>
          </div>
          <div id="sidebar">
            <div id="icons"/>
            <OrderNotifications
              :shop="container.canonical_name"
              :show="showOrderNotification"
            />              <!-- product stock -->
            <ProductStock :products="products" />
            <headlines />
            <action-buttons
              v-if="Object.keys(container).length"
              :has-swiper="hasSwiper"
              :shop="container"/>
          </div>
          <div id="mainpagecontent">
            <div id="maincontent">
              <router-view
                :shop="container"
                :orders="orders"
                :products="products"
                :prices="prices"
                @simple-one="simpleOne"
                @simple-two="simpleTwo"
                @busy-one="busyOne"
                @busy-two="busyTwo"
                @product-changed="getProducts"
                @price-changed="getPrices"/>
            </div>
          </div>
          <div class="clear"/>
        </div>
      </div>
      <div
        v-if="container.shop_style == 2"
        class="shop-body">
        <div class="header">
          <div class="headerwidthcontainer">
            <div id="gear">&nbsp;</div>
            <div id="shopname">{{ container.name }}</div>
            <div id="yatlogo">
              <img
                id="yatlogoimg"
                :src="logo"
                width="98"
                height="81">
            </div>
          </div>
        </div>
        <div class="contentwidthcontainer">
          <div
            v-if="container.admin"
            id="menu">
            <ul
              id="nav"
              class="tab-buttons">
              <router-link
                :to="{name: 'containersmain'}"
                tag="li">
                <a
                  :class="{selected: (this.$route.name === 'containersmain')}"
                  :orders="orders"
                  class="tab">Main Page</a>
              </router-link>
              <router-link
                :to="{name: 'containersprice'}"
                tag="li">
                <a
                  :class="{selected: (this.$route.name === 'containersprice')}"
                  class="tab">Edit Price
                </a>
              </router-link>
              <router-link
                :to="{name: 'containersorders'}"
                tag="li">
                <a
                  :class="{selected: (this.$route.name === 'containersorders')}"
                  class="tab">Orders
                </a>
              </router-link>
              <router-link
                :to="{name: 'containersaccounting'}"
                tag="li">
                <a
                  :class="{selected: (this.$route.name === 'containersaccounting')}"
                  class="tab">Accounting
                </a>
              </router-link>
              <div class="clear"/>
            </ul>
          </div>
          <div id="sidebar">
            <div id="icons"/>
            <OrderNotifications
              :shop="container.canonical_name"
              :show="showOrderNotification"
            />
            <!-- product stock -->
            <ProductStock :products="products" />
            <headlines />
            <action-buttons
              v-if="Object.keys(container).length"
              :has-swiper="hasSwiper"
              :shop="container" />
          </div>
          <div id="mainpagecontent">
            <div id="maincontent">
              <router-view
                :shop="container"
                :orders="orders"
                :products="products"
                :prices="prices"
                @simple-one="simpleOne"
                @simple-two="simpleTwo"
                @busy-one="busyOne"
                @busy-two="busyTwo"
                @price-changed="getProducts"/>
              <img
                id="containerbottom"
                src="/images/shop/containers/container-contentbottom.jpg">
            </div>
          </div>
          <div class="clear"/>
        </div>
      </div>
    </div>
  </section>
</template>

<script>
import ShopBaseView from "../shopBase.js";
import Headlines from "../Headlines.vue";
import ProductStock from "../../../../shared/views/shopTransactions/ProductStock.vue";
import OrderNotifications from "../../../../shared/views/shopTransactions/OrderNotification.vue";
import ActionButtons from "../ActionButtons.vue";

export default {
  components: {
    Headlines,
    ActionButtons,
    ProductStock,
    OrderNotifications
  },
  extends: ShopBaseView,
  data() {
    return {
      logo: app.network.data.shop_logo,
      container: {},
      hasSwiper: app.computerSettings.swiper,
      orders:[],
      products: [],
      prices: [],
      intervalID: "",
      showOrderNotification:false,
      // this tracks when to show a notification
      orderAmount:null
    };
  },
  watch: {
    // this is to handle notifications that could come in while on the order view, and to dismiss the view
    "$route" (to, from) {
      if(to.name === "containersorders"){
        this.showOrderNotification = false;
      }
      if(from.name === "containersorders"){
        this.orderAmount = this.orders.length;
      }
    }
  },
  created: function () {
    let self = this;
    this.getData();
    this.getOrders();
    this.getProducts();
    this.getPrices();
    this.intervalID = setInterval( function(){
      self.getOrders();
      self.getPrices();
      self.getProducts();
    }, 10000);
  },
  destroyed(){
    clearInterval(this.intervalID);
  },
  beforeMount: function () {
    this.$router.push({name: "containersmain"});
  },
  methods: {
    getData() {
      app.session.SetSession()
        .then( () => {
        app.api.Get( "/containers/" + app.session.data.id )
          .then( Response => {
            console.log(Response);
            this.container = Response;
            app.Message( "Successfully loaded the Container Shop!", "success" );
          })
          .catch( x => app.Message( x.error, "error" ) );
        });
    },
    simpleOne() {
      this.container.shop_style = 1;
      this.container.shop_color = 1;
    },
    simpleTwo() {
      this.container.shop_style  = 1;
      this.container.shop_color = 2;
    },
    busyOne() {
      this.container.shop_style  = 2;
      this.container.shop_color = 1;
    },
    busyTwo() {
      this.container.shop_style  = 2;
      this.container.shop_color = 2;
    },
    getProducts(){
      app.api.Get("/products/?type=briefcase")
        .then( Response => {
          this.products = Response.map(product => {product.price = product.price.toFixed(2); return product;});
        })
      .catch( x => app.Message( x.error, "error" ) );
    },
    getPrices(){
      app.api.Get("/prices/?type=briefcase")
      .then( Response => {
        this.prices = Response;
      })
      .catch( x => app.Message( x.error, "error" ) );
    },
    getOrders(){
      app.api.Get( "/orders/bytype/?type=briefcase")
        .then( Response => {
          this.orders = Response;
          // this is to handle the initial showing of the order notification, and handle updates
          if(this.orderAmount === null){
            this.orderAmount = this.orders.length;
          }
          if(this.$route.name !== "containersorders"){
            if(this.orders.length > this.orderAmount){
              this.orderAmount = this.orders.length;
              this.showOrderNotification = true;
            }
          }
        })
      .catch( x => app.Message( x.error, "error" ) );
    }
  },
};
</script>

<style lang="less">
  @import '../../shared.less';
</style>

<style lang="less">

.containers.layout1.color1 {
  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @bgcontentimage: url(/images/shop/containers/containerbg.jpg);
  @tabfontcolor: #fff;


  @maincontentcolor: #131736;

  .shopbuttonstyles() {
    background-color: #ffa400;
    border-color: #ffdb99;
    color: #fff;
  }
  .bodyback() {
    background-image: @bgcontentimage;
    background-repeat:no-repeat;
    background-position:center 0rem;
    background-size:97.8rem 60rem;
  }
  .fullback() {
    background-image: @bgimage;
    background-repeat:repeat;
    background-position:center 0rem;
    background-size:23.1rem 22rem;
    height:45.9rem;
  }
  // color 1
  @shoptitlecolor: #325873;
  @logoborder: 0.5rem solid #325873;
  @shopdesccolor:#fff;
  @homemsgcolor:#144a68;
  @activetabcolor: #dbaf34;
  @navbgcolor: #fccb42;
  @hometxtcolor:#008e18;
  @shopbackgroundcolor:#fccb42;
  @bgimage: url(/images/shop/containers/container-backbg.jpg);
  @bgnav: url(/images/shop/containers/containers-navbg.jpg);
  @tabactivefontcolor: #325873;
  @widgetbgtop: url(/images/shop/containers/bg-widget-top-yellow.png);
  @widgetbgbottom: url(/images/shop/containers/bg-widget-bottom-yellow.png);
  @buttoncolor: white;
  .bggradient() {
    background: -moz-linear-gradient(top,  rgba(255,255,255,.3) 15%, rgba(255,255,255,0) 40%, rgba(255,255,255,0) 100%);
    background: linear-gradient(to bottom,  rgba(255,255,255,.3) 15%,rgba(255,255,255,0) 40%,rgba(255,255,255,0) 100%);
  }

  @import './containerLayout1.less';

}
</style>

<style lang="less">

.containers.layout1.color2 {
  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @bgcontentimage: url(/images/shop/containers/containerbg.jpg);
  @tabfontcolor: #fff;


  @maincontentcolor: #131736;

  .shopbuttonstyles() {
    background-color: #ffa400;
    border-color: #ffdb99;
    color: #fff;
  }
  .bodyback() {
    background-image: @bgcontentimage;
    background-repeat:no-repeat;
    background-position:center 0rem;
    background-size:97.8rem 60rem;
  }
  .fullback() {
    background-image: @bgimage;
    background-repeat:repeat;
    background-position:center 0rem;
    background-size:23.1rem 22rem;
    height:45.9rem;
  }
  //color2
  @shoptitlecolor: #d67822;
  @logoborder: 0.5rem solid #d67822;
  @shopdesccolor:#fff;
  @homemsgcolor:#7f0000;
  @activetabcolor: #1d4091;
  @navbgcolor: #2e55b0;
  @hometxtcolor:#337399;
  @shopbackgroundcolor:#2e55b0;
  @bgimage: url(/images/shop/containers/container-backgreenbg.jpg);
  @bgnav: url(/images/shop/containers/containers-navbg-green.jpg);
  @tabactivefontcolor: #fff;
  @widgetbgtop: url(/images/shop/containers/bg-widget-top-green.jpg);
  @widgetbgbottom: url(/images/shop/containers/bg-widget-bottom-green.jpg);
  @buttoncolor: white;
  .bggradient() {
    background: -moz-linear-gradient(top,  rgba(255,255,255,.06) 15%, rgba(255,255,255,0) 40%, rgba(255,255,255,0) 100%);
    background: linear-gradient(to bottom,  rgba(255,255,255,.06) 15%,rgba(255,255,255,0) 40%,rgba(255,255,255,0) 100%);
  }
  @import './containerLayout1.less';
}
</style>

<style lang="less">

.containers.layout2.color1 {
  /* Containers common */

  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: right;
  @maincontentfloat:left;
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @bgcontentimage: url(/images/shop/containers/containerbg.jpg);
  @tabfontcolor: #fff;


  @maincontentcolor: #131736;

  .shopbuttonstyles() {
    background-color: #ffa400;
    border-color: #ffdb99;
    color: #fff;
  }
  .bodyback() {
    background-image: @bgcontentimage;
    background-repeat:no-repeat;
    background-position:center 0rem;
    background-size:97.8rem 60rem;
  }
  .fullback() {
    background-image: @bgimage;
    background-repeat:repeat;
    background-position:center 0rem;
    background-size:23.1rem 22rem;
    height:45.9rem;
  }

  // Container color 1
  // Container color 1
  @gear:url(/images/shop/containers/gear2.png);
  @shoptitlecolor: #362b19;
  @logoborder: 0.5rem solid #42351f;
  @headerbg:url(/images/shop/containers/container2bg.jpg);
  @shopdesccolor:#362b19;
  @homemsgcolor:#144a68;
  @activetabcolor: #dbaf34;
  @navbgcolor: #fccb42;
  @hometxtcolor:#008e18;
  @shopbackgroundcolor:#fccb42;
  @maincontenth1:#362b19;
  @bgimage: url(/images/shop/containers/container2-backbg.jpg);
  @bgimage2:url(/images/shop/containers/container2contentbg.jpg);
  @bgnav: url(/images/shop/containers/containers-navbg.jpg);
  @tabactivefontcolor: #325873;
  @widgetbgtop: url(/images/shop/containers/bg-widget-top-brown.jpg);
  @widgetbgbottom: url(/images/shop/containers/bg-widget-bottom-brown.jpg);
  @buttoncolor: white;
  .bggradient() {
    background: -moz-linear-gradient(top,  rgba(255,255,255,.3) 15%, rgba(255,255,255,0) 40%, rgba(255,255,255,0) 100%);
    background: linear-gradient(to bottom,  rgba(255,255,255,.3) 15%,rgba(255,255,255,0) 40%,rgba(255,255,255,0) 100%);
  }
  @import './containerLayout2.less';
}
</style>

<style lang="less">

.containers.layout2.color2 {
  /* Containers common */

  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: right;
  @maincontentfloat:left;
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @bgcontentimage: url(/images/shop/containers/containerbg.jpg);
  @tabfontcolor: #fff;


  @maincontentcolor: #131736;

  .shopbuttonstyles() {
    background-color: #ffa400;
    border-color: #ffdb99;
    color: #fff;
  }
  .bodyback() {
    background-image: @bgcontentimage;
    background-repeat:no-repeat;
    background-position:center 0rem;
    background-size:97.8rem 60rem;
  }
  .fullback() {
    background-image: @bgimage;
    background-repeat:repeat;
    background-position:center 0rem;
    background-size:23.1rem 22rem;
    height:45.9rem;
  }

  //color2
  @gear:url(/images/shop/containers/gear2-2.png);
  @shoptitlecolor: #d5731a;
  @logoborder: 0.5rem solid #d67822;
  @headerbg:url(/images/shop/containers/container2bg-2.jpg);
  @shopdesccolor:#362b19;
  @homemsgcolor:#7f0000;
  @activetabcolor: #1d4091;
  @navbgcolor: #2e55b0;
  @hometxtcolor:#337399;
  @shopbackgroundcolor:#2e55b0;
  @maincontenth1:#d5731a;
  @bgimage: url(/images/shop/containers/container2-backbg.jpg);
  @bgimage2:url(/images/shop/containers/container2contentbg2.jpg);
  @bgnav: url(/images/shop/containers/containers-navbg-green.jpg);
  @tabactivefontcolor: #fff;
  @widgetbgtop: url(/images/shop/containers/bg-widget-top-white.jpg);
  @widgetbgbottom: url(/images/shop/containers/bg-widget-bottom-white.jpg);
  @buttoncolor: white;
  .bggradient() {
    background: -moz-linear-gradient(top,  rgba(255,255,255,.06) 15%, rgba(255,255,255,0) 40%, rgba(255,255,255,0) 100%);
    background: linear-gradient(to bottom,  rgba(255,255,255,.06) 15%,rgba(255,255,255,0) 40%,rgba(255,255,255,0) 100%);
  }
  @import './containerLayout2.less';
}
</style>

